﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;
using iqiyiWin.Constant;
using iqiyiWin.Model;
using iqiyiWin.Response.Cinema.CinemaItem;
using iqiyiWin.Response.Cinema.Citites;
using iqiyiWin.Util;
using Newtonsoft.Json;

namespace iqiyiWin.Api
{
    public class Cinema
    {
        public static List<IqiyiCity> GetCities()
        {
            var headers = new SortedDictionary<string, string>();

            headers.Add("version", IqiyiVersion.Version);
            headers.Add("os", IqiyiVersion.Os);
            headers.Add("src", IqiyiVersion.Src);
            headers.Add("platform", IqiyiVersion.Platform);
            headers.Add("appid", IqiyiVersion.Appid);
            headers.Add("dvsrc", IqiyiVersion.Dvsrc);
            headers.Add("dfp", IqiyiVersion.Dfp());
            headers.Add("ts", DateUtils.GetTimeStampOfMilliseconds().ToString());
            headers.Add("nonce", IqiyiVersion.Nonce());

            headers.Add("sig", IqiyiSign.Sign(headers));

            var queryText = UrlUtils.BuildQueryStringUrl(headers);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.GET_CITIES + queryText, headers);

            var response = JsonConvert.DeserializeObject<CityListResponse>(responseStr);

            var cityList = new List<IqiyiCity>();

            if (response != null && response.Code == "A00000")
            {
                foreach (var cItem in response.Data.Cities)
                {
                    foreach (var item in cItem.Value)
                    {
                        cityList.Add(item);
                    }
                }
                 //UILogUtils.Info($"爱奇艺票务 【获取城市列表】成功；");
                return cityList;
            }
            else
            {
                //UILogUtils.Error($"爱奇艺票务 【获取城市列表】失败:  {(response == null ? responseStr : response.Msg)}");
                return cityList;
            }
        }
        public static List<IqiyiCinema> GetCinemaList(IqiyiCity city, int pageIndex = 0)
        {
            var headers = new SortedDictionary<string, string>();

            headers.Add("version", IqiyiVersion.Version);
            headers.Add("os", IqiyiVersion.Os);
            headers.Add("src", IqiyiVersion.Src);
            headers.Add("platform", IqiyiVersion.Platform);
            headers.Add("appid", IqiyiVersion.Appid);
            headers.Add("dvsrc", IqiyiVersion.Dvsrc);
            headers.Add("dfp", IqiyiVersion.Dfp());
            headers.Add("ts", DateUtils.GetTimeStampOfMilliseconds().ToString());
            headers.Add("nonce", IqiyiVersion.Nonce());
            headers.Add("cityId", city.CityId.ToString());
            headers.Add("page", pageIndex.ToString());
            headers.Add("pageCount", "20");

            headers.Add("sig", IqiyiSign.Sign(headers));

            var queryText = UrlUtils.BuildQueryStringUrl(headers);

            var responseStr = HttpUtils.DoGet(new CookieContainer(), Domain.REFERER_DOMAIN, Domain.TICKET_IQIYI + ApiConstant.GET_CINEMA_LIST + queryText, headers);

            var response = JsonConvert.DeserializeObject<CinemaResponse>(responseStr);

            var cinemaList = new List<IqiyiCinema>();

            if (response != null && response.Code == "A00000")
            {

                foreach (var item in response.Data.Cinemas)
                {
                    cinemaList.Add(item);
                }
                if (response.HasNext)
                {
                    var nextCinemaList =GetCinemaList(city, pageIndex + 1);
                    cinemaList.AddRange(nextCinemaList);
                }
                //UILogUtils.Info($"爱奇艺票务 【获取影院列表】成功；");
                return cinemaList;
            }
            else
            {
                //UILogUtils.Error($"爱奇艺票务 【获取影院列表】失败:  {(response == null ? responseStr : response.Msg)}");
                return cinemaList;
            }
        }
    }
}
